Method: VirtualBox::AbstractModel::Attributable#write_attribute

Defined in:
lib/virtualbox/abstract_model/attributable.rb

#write_attribute(name, value) ⇒ Object

Writes an attribute. This method ignores the readonly option on attribute definitions. This method is mostly meant for internal use on setting attributes (including readonly attributes), whereas users of a class which includes this module should use the accessor methods, such as name=.



233
234
235
# File 'lib/virtualbox/abstract_model/attributable.rb', line 233

def write_attribute(name, value)
  attributes[name] = value
end