Method: VirtualBox::COM::MSCOMInterface#virtualbox

Defined in:
lib/virtualbox/com/mscom_interface.rb

#virtualboxObject (readonly)

The VirtualBox and Session interfaces, both of which are extremely important in interfacing with the VirtualBox API. Once these have been initialized, all other parts of the API can be accessed via these instances.



8
9
10
# File 'lib/virtualbox/com/mscom_interface.rb', line 8

def virtualbox
  @virtualbox
end