Method: VirtualBox::VM#state

Defined in:
lib/virtualbox/vm.rb

#state(suppress_state_reload = false) ⇒ String

State of the virtual machine. Returns the state of the virtual machine. This state will represent the state that was assigned when the VM was found unless reload is set to true.

Parameters:

  • reload (Boolean)

    If true, will reload the state to current value.

Returns:

  • (String)

    Virtual machine state.



301
302
303
304
305
306
307
308
# File 'lib/virtualbox/vm.rb', line 301

def state(suppress_state_reload=false)
  if !suppress_state_reload
    load_interface_attribute(:state, interface)
    clear_dirty!(:state)
  end

  read_attribute(:state)
end