Method: VirtualBox::AbstractModel#save_attribute
- Defined in:
- lib/virtualbox/abstract_model.rb
#save_attribute(key, value, *args) ⇒ Object
Saves a single attribute of the model. This method on the abstract model does nothing on its own, and is expected to be overridden by any subclasses.
This method clears the dirty status of the attribute.
142 143 144 |
# File 'lib/virtualbox/abstract_model.rb', line 142 def save_attribute(key, value, *args) clear_dirty!(key) end |