Method: VirtualBox::HostNetworkInterface.create
- Defined in:
- lib/virtualbox/host_network_interface.rb
.create(proxy, interface) ⇒ Object
Creates a host only network interface. This method should not
be called directly. Instead, the create method on the
Global#host relationship should be called instead. Example:
VirtualBox::Global.global.host.network_interfaces.create
The above will create a host only network interface, add it to the collection, and will return the instance of the new interface.
48 49 50 51 52 53 |
# File 'lib/virtualbox/host_network_interface.rb', line 48 def create(proxy, interface) inet, progress = interface.create_host_only_network_interface progress.wait new(inet) end |